FilterData

Struct FilterData 

pub struct FilterData {
    pub filter: Filter,
    pub transform: Affine,
    pub filter_padding: PaddingU16,
    pub source_padding: PaddingU16,
}
Precomputed data for a filter layer.

Fields

filter: Filter

The underlying filter.

transform: Affine

The transform that was in place when the filter layer was invoked.

filter_padding: PaddingU16

Padding that needs to be added for the area where the filter is applied.

See Filter::filter_expansion.

source_padding: PaddingU16

Padding that needs to be added to the source region for correct filter application.

See Filter::source_expansion.

Implementations

Source

impl FilterData

pub fn new(filter: Filter, transform: Affine) -> Self

Create precomputed data for a filter and transform.

pub fn source_shift(&self) -> (u16, u16)

By how much to shift all rendered contents to ensure that all rendered contents are visible in the viewport [0, 0, width, height].